@@ -11,11 +11,11 @@
 # under the License.
 
 import glob
+from importlib import import_module
 import os
 
-from django.core.management.base import CommandError  # noqa
-from django.core.management.templates import TemplateCommand  # noqa
-from importlib import import_module
+from django.core.management.base import CommandError
+from django.core.management.templates import TemplateCommand
 
 import horizon
 
@@ -59,7 +59,7 @@ class Command(TemplateCommand):
                                "Python module and cannot be used as an app "
                                "name. Please try another name." % dash_name)
 
-        super(Command, self).handle('dash', dash_name, **options)
+        super().handle('dash', dash_name, **options)
 
         target = options.pop("target", None)
         if not target:
