@@ -25,14 +25,18 @@
    * used with the Eucalyptus third-party MagicSearch module at
    * https://github.com/eucalyptus/magic-search.
    *
-   * | Directives                                                        |
-   * |-------------------------------------------------------------------|
-   * | {@link MagicSearch.directive:hzMagicSearchBar `hzMagicSearchBar`} |
-   * | {@link MagicSearch.directive:magicOverrides `magicOverrides`}     |
-   * | {@link MagicSearch.directive:stMagicSearch `stMagicSearch`}       |
-   *
    */
   angular
-    .module('horizon.framework.widgets.magic-search', ['ui.bootstrap']);
+    .module('horizon.framework.widgets.magic-search', ['ui.bootstrap'])
+    .constant(
+      'horizon.framework.widgets.magic-search.events', {
+        TEXT_SEARCH: 'textSearch',
+        SEARCH_UPDATED: 'searchUpdated',
+        CHECK_FACETS: 'checkFacets',
+        FACETS_CHANGED: 'facetsChanged',
+        SERVER_SEARCH_UPDATED: 'serverSearchUpdated',
+        INIT_SEARCH: 'initSearch'
+      }
+    );
 
 })();
