@@ -22,10 +22,11 @@
     .controller('WizardModalController', WizardModalController);
 
   WizardModalController.$inject = [
-    '$modalInstance',
+    '$uibModalInstance',
     '$scope',
-    'workflow', // modal injected
-    'submit'    // modal injected
+    'workflow', // WizardModalService injected
+    'submit',   // WizardModalService injected
+    'data'      // WizardModalService injected
   ];
 
   /**
@@ -38,21 +39,26 @@
    * This controller sets the modal actions and workflow on the given scope
    * as the Wizard needs them defined on the scope.
    */
-  function WizardModalController($modalInstance, $scope, workflow, submit) {
+  function WizardModalController($uibModalInstance, $scope, workflow, submit, data) {
 
     /* eslint-disable angular/controller-as */
     $scope.close = close;
     $scope.cancel = cancel;
     $scope.submit = submit;
     $scope.workflow = workflow;
+    // copy over the data (we copy directly for backwards compatibility of access
+    // since these properties used to be assigned directly on the scope)
+    angular.forEach(data, function copy(value, key) {
+      $scope[key] = value;
+    });
     /* eslint-enable angular/controller-as */
 
     function close(args) {
-      $modalInstance.close(args);
+      $uibModalInstance.close(args);
     }
 
     function cancel() {
-      $modalInstance.dismiss('cancel');
+      $uibModalInstance.dismiss('cancel');
     }
   }
 
