@@ -1,3 +1,17 @@
+/**
+ * Licensed under the Apache License, Version 2.0 (the "License"); you may
+ * not use this file except in compliance with the License. You may obtain
+ * a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+ * License for the specific language governing permissions and limitations
+ * under the License.
+ */
+
 /* This is the base Horizon JavaScript object. There is only ever one of these
  * loaded (referenced as horizon with a lower-case h) which happens immediately
  * after the definition below.
@@ -33,6 +47,9 @@ var Horizon = function () {
    */
   horizon.conf = {};
 
+  // default languageCode for tests that run without Django context
+  horizon.languageCode = 'en';
+
   return horizon;
 };
 
