@@ -121,7 +121,7 @@ horizon.modals.init_wizard = function () {
     });
 
     // Temporarilly remove "disabled" attribute to get the values serialized
-    var disabled = $form.find('select[disabled="disabled"]').removeAttr("disabled");
+    var disabled = $form.find('select[disabled="disabled"]').prop("disabled", false);
 
     // Send the data for validation.
     $.ajax({
@@ -169,7 +169,7 @@ horizon.modals.init_wizard = function () {
           });
           // Focus the first invalid field.
           if (first_field) {
-            $field.focus();
+            $field.trigger('focus');
             first_field = false;
           }
         });
@@ -321,16 +321,35 @@ horizon.addInitFunction(horizon.modals.init = function() {
         add_to_field_header = jqXHR.getResponseHeader("X-Horizon-Add-To-Field"),
         json_data, field_to_update;
       if (redirect_header === null) {
-        $('.ajax-modal, .dropdown-toggle').removeAttr("disabled");
+        $('.ajax-modal, .dropdown-toggle').prop("disabled", false);
       }
 
-      if (redirect_header) {
+      content_disposition = jqXHR.getResponseHeader("content-disposition");
+      if (content_disposition && content_disposition.lastIndexOf("attachment;") !== -1) {
+        // if the response was a file, we download the data
+        var file_name_regex = /(?:^|\s)filename=(.*?)(?:\s|$)/g;
+        var filename = file_name_regex.exec(content_disposition)[1];
+        var modal_attachment_link = document.createElement('a');
+        modal_attachment_link.setAttribute("id", "modal_attachment_link");
+        modal_attachment_link.setAttribute("style", "display:none");
+        var dataStr = "data:text/plain;charset=utf-8," + encodeURIComponent(data);
+        modal_attachment_link.setAttribute("href", dataStr);
+        modal_attachment_link.setAttribute("download", filename);
+        var modal_wrapper = document.getElementById("modal_wrapper");
+        modal_wrapper.appendChild(modal_attachment_link);
+        modal_attachment_link.click();
+        modal_attachment_link.remove();
+
+        if (redirect_header) {
+          location.href = redirect_header;
+        }
+      } else if (redirect_header) {
         location.href = redirect_header;
       } else if (add_to_field_header) {
-        json_data = $.parseJSON(data);
+        json_data = JSON.parse(data);
         field_to_update = $("#" + add_to_field_header);
         field_to_update.append("<option value='" + json_data[0] + "'>" + json_data[1] + "</option>");
-        field_to_update.change();
+        field_to_update.trigger("change");
         field_to_update.val(json_data[0]);
       } else {
         horizon.modals.success(data, textStatus, jqXHR);
@@ -342,7 +361,7 @@ horizon.addInitFunction(horizon.modals.init = function() {
       if (jqXHR.getResponseHeader('logout')) {
         location.href = jqXHR.getResponseHeader("X-Horizon-Location");
       } else {
-        $('.ajax-modal, .dropdown-toggle').removeAttr("disabled");
+        $('.ajax-modal, .dropdown-toggle').prop("disabled", false);
         $formElement.closest(".modal").modal("hide");
         horizon.toast.add("danger", gettext("There was an error submitting the form. Please try again."));
       }
@@ -398,7 +417,7 @@ horizon.addInitFunction(horizon.modals.init = function() {
   // Position modal so it's in-view even when scrolled down.
   $document.on('show.bs.modal', '.modal', function (evt) {
     // avoid closing the modal when escape is pressed on a select input
-    $("select", evt.target).keyup(function (e) {
+    $("select", evt.target).on('keyup', function (e) {
       if (e.keyCode === 27) {
         // remove the focus on the select, so double escape close the modal
         e.target.blur();
@@ -409,7 +428,7 @@ horizon.addInitFunction(horizon.modals.init = function() {
 
   // Focus the first usable form field in the modal for accessibility.
   horizon.modals.addModalInitFunction(function (modal) {
-    $(modal).find(":text, select, textarea").filter(":visible:first").focus();
+    $(modal).find(":text, select, textarea").filter(":visible:first").trigger("focus");
   });
 
   horizon.modals.addModalInitFunction(function(modal) {
