@@ -20,8 +20,9 @@ import os
 import socket
 
 from horizon.defaults import *  # noqa: F401,F403,H303
-from openstack_auth.defaults import *  # noqa: F401,F403,H303
-from openstack_dashboard.utils import settings as settings_utils
+
+from openstack_auth.defaults import *  # noqa: F401,F403,H303,I100
+from openstack_dashboard.utils import settings as settings_utils  # noqa: I100
 
 socket.setdefaulttimeout(1)
 
@@ -37,7 +38,6 @@ TESTSERVER = 'http://testserver'
 SECRET_KEY = 'elj1IWiLoWHgcyYxFVLj7cM5rGOOxWl0'
 
 USE_I18N = True
-USE_L10N = True
 USE_TZ = True
 
 DATABASES = {'default': {'ENGINE': 'django.db.backends.sqlite3'}}
@@ -51,8 +51,6 @@ INSTALLED_APPS = (
     'django.contrib.humanize',
     'django.contrib.auth',
     'django.contrib.contenttypes',
-    'horizon.test.django_pyscss_fix',
-    'django_pyscss',
     'compressor',
     'horizon',
     'horizon.test',
