@@ -14,7 +14,6 @@
 import datetime
 import uuid
 
-from django.utils import datetime_safe
 from keystoneauth1.access import access
 from keystoneauth1.access import service_catalog
 from keystoneclient.v3 import domains
@@ -175,8 +174,8 @@ def generate_test_data(service_providers=False, endpoint='localhost'):
     }
 
     # Tokens
-    tomorrow = datetime_safe.datetime.now() + datetime.timedelta(days=1)
-    expiration = datetime_safe.datetime.isoformat(tomorrow)
+    tomorrow = datetime.datetime.now() + datetime.timedelta(days=1)
+    expiration = datetime.datetime.isoformat(tomorrow)
     auth_token = uuid.uuid4().hex
 
     auth_response_headers = {
@@ -255,6 +254,30 @@ def generate_test_data(service_providers=False, endpoint='localhost'):
         body=domain_token_dict
     )
 
+    system_token_dict = {
+        'token': {
+            'methods': ['password'],
+            'expires_at': expiration,
+            'system': {
+                'all': True,
+            },
+            'user': {
+                'id': user_dict['id'],
+                'name': user_dict['name'],
+                'domain': {
+                    'id': domain_dict['id'],
+                    'name': domain_dict['name']
+                }
+            },
+            'roles': [role_dict],
+            'catalog': [keystone_service, nova_service]
+        }
+    }
+    test_data.system_scoped_access_info = access.create(
+        resp=auth_response,
+        body=system_token_dict
+    )
+
     unscoped_token_dict = {
         'token': {
             'methods': ['password'],
