@@ -91,7 +91,7 @@ class Service(base.APIDictWrapper):
         self.region = region
 
     def __str__(self):
-        if(self.type == "identity"):
+        if self.type == "identity":
             return _("%(type)s (%(backend)s backend)") \
                 % {"type": self.type, "backend": keystone_backend_name()}
         return self.type
@@ -221,7 +221,7 @@ def domain_delete(request, domain_id):
 
 @profiler.trace
 def domain_list(request):
-    manager = keystoneclient(request, admin=True).domains
+    manager = keystoneclient(request, admin=True, force_scoped=True).domains
     return manager.list()
 
 
@@ -499,6 +499,47 @@ def user_update_tenant(request, user, project, admin=True):
     return manager.update(user, project=project)
 
 
+@profiler.trace
+def credential_create(request, user, type, blob, project=None):
+    manager = keystoneclient(request).credentials
+    return manager.create(user=user, type=type, blob=blob, project=project)
+
+
+@profiler.trace
+def credential_delete(request, credential_id):
+    manager = keystoneclient(request, admin=True).credentials
+    return manager.delete(credential_id)
+
+
+@profiler.trace
+def credential_get(request, credential_id, admin=True):
+    manager = keystoneclient(request, admin=admin).credentials
+    return manager.get(credential_id)
+
+
+@profiler.trace
+def credentials_list(request, user_id=None, filters=None):
+    manager = keystoneclient(request).credentials
+    kwargs = {"user_id": user_id}
+    if filters:
+        kwargs.update(filters)
+    return manager.list(**kwargs)
+
+
+@profiler.trace
+def credential_update(request, credential_id, user,
+                      type=None, blob=None, project=None):
+    manager = keystoneclient(request, admin=True).credentials
+    try:
+        return manager.update(credential=credential_id,
+                              user=user,
+                              type=type,
+                              blob=blob,
+                              project=project)
+    except keystone_exceptions.Conflict:
+        raise exceptions.Conflict()
+
+
 @profiler.trace
 def group_create(request, domain_id, name, description=None):
     manager = keystoneclient(request, admin=True).groups
@@ -799,35 +840,6 @@ def get_default_role(request):
     return DEFAULT_ROLE
 
 
-def ec2_manager(request):
-    client = keystoneclient(request)
-    if hasattr(client, 'ec2'):
-        return client.ec2
-
-    from keystoneclient.v3 import ec2
-    return ec2.EC2Manager(client)
-
-
-@profiler.trace
-def list_ec2_credentials(request, user_id):
-    return ec2_manager(request).list(user_id)
-
-
-@profiler.trace
-def create_ec2_credentials(request, user_id, tenant_id):
-    return ec2_manager(request).create(user_id, tenant_id)
-
-
-@profiler.trace
-def get_user_ec2_credentials(request, user_id, access_token):
-    return ec2_manager(request).get(user_id, access_token)
-
-
-@profiler.trace
-def delete_user_ec2_credentials(request, user_id, access_token):
-    return ec2_manager(request).delete(user_id, access_token)
-
-
 def keystone_can_edit_domain():
     can_edit_domain = setting_utils.get_dict_config(
         'OPENSTACK_KEYSTONE_BACKEND', 'can_edit_domain')
