@@ -44,17 +44,17 @@ def openstack(request):
 
     # Auth/Keystone context
     context.setdefault('authorized_tenants', [])
-    if request.user.is_authenticated():
+    if request.user.is_authenticated:
         context['authorized_tenants'] = [
             tenant for tenant in
             request.user.authorized_tenants if tenant.enabled]
 
     # Region context/support
-    available_regions = getattr(settings, 'AVAILABLE_REGIONS', [])
+    available_regions = settings.AVAILABLE_REGIONS
     regions = {'support': len(available_regions) > 1,
                'current': {'endpoint': request.session.get('region_endpoint'),
                            'name': request.session.get('region_name')},
-               'available': [{'endpoint': region[0], 'name':region[1]} for
+               'available': [{'endpoint': region[0], 'name': region[1]} for
                              region in available_regions]}
 
     # K2K Federation Service Providers context/support
@@ -84,24 +84,18 @@ def openstack(request):
     context['regions'] = regions
 
     # Adding webroot access
-    context['WEBROOT'] = getattr(settings, "WEBROOT", "/")
+    context['WEBROOT'] = settings.WEBROOT
 
-    user_menu_links = getattr(settings, "USER_MENU_LINKS", [])
-
-    if not getattr(settings, "SHOW_KEYSTONE_V2_RC", True):
-        user_menu_links = [
-            link for link in user_menu_links
-            if 'horizon:project:api_access:openrcv2' != link['url']]
-
-    context['USER_MENU_LINKS'] = user_menu_links
+    context['USER_MENU_LINKS'] = settings.USER_MENU_LINKS
+    context['LOGOUT_URL'] = settings.LOGOUT_URL
 
     # Adding profiler support flag
-    profiler_settings = getattr(settings, 'OPENSTACK_PROFILER', {})
-    profiler_enabled = profiler_settings.get('enabled', False)
+    profiler_settings = settings.OPENSTACK_PROFILER
+    profiler_enabled = profiler_settings['enabled']
     context['profiler_enabled'] = profiler_enabled
     if profiler_enabled and 'profile_page' in request.COOKIES:
         index_view_id = request.META.get(profiler.ROOT_HEADER, '')
-        hmac_keys = profiler_settings.get('keys', [])
+        hmac_keys = profiler_settings['keys']
         context['x_trace_info'] = profiler.update_trace_headers(
             hmac_keys, parent_id=index_view_id)
 
