@@ -49,10 +49,11 @@ class CreateAggregateWorkflowTests(BaseAggregateWorkflowTests):
 
         self.assertTemplateUsed(res, constants.AGGREGATES_CREATE_VIEW_TEMPLATE)
         self.assertEqual(workflow.name, workflows.CreateAggregateWorkflow.name)
-        self.assertQuerysetEqual(
+        self.assertQuerySetEqual(
             workflow.steps,
             ['<SetAggregateInfoStep: set_aggregate_info>',
-             '<AddHostsToAggregateStep: add_host_to_aggregate>'])
+             '<AddHostsToAggregateStep: add_host_to_aggregate>'],
+            transform=repr)
         self.mock_service_list.assert_called_once_with(
             test.IsHttpRequest(),
             binary='nova-compute')
