@@ -16,7 +16,7 @@
 import logging
 
 from django import shortcuts
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from horizon import exceptions
 from horizon import messages
