@@ -12,7 +12,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from horizon import exceptions
 from horizon import tables
@@ -30,8 +30,7 @@ class AdminDeleteImage(project_tables.DeleteImage):
     def allowed(self, request, image=None):
         if image and image.protected:
             return False
-        else:
-            return True
+        return True
 
 
 class AdminEditImage(project_tables.EditImage):
@@ -50,7 +49,7 @@ class UpdateMetadata(tables.LinkAction):
 
     def __init__(self, attrs=None, **kwargs):
         kwargs['preempt'] = True
-        super(UpdateMetadata, self).__init__(attrs, **kwargs)
+        super().__init__(attrs, **kwargs)
 
     def get_link_url(self, datum):
         image_id = self.table.get_object_id(datum)
@@ -86,10 +85,9 @@ class AdminImageFilterAction(tables.FilterAction):
 
 
 class AdminImagesTable(project_tables.ImagesTable):
-    name = tables.Column("name",
-                         link="horizon:admin:images:detail",
-                         truncate=40,
-                         verbose_name=_("Image Name"))
+    name = tables.WrappingColumn(project_tables.get_image_name,
+                                 link="horizon:admin:images:detail",
+                                 verbose_name=_("Image Name"))
     tenant = tables.Column(lambda obj: getattr(obj, 'tenant_name', obj.owner),
                            verbose_name=_("Project"))
 
