@@ -12,8 +12,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf.urls import patterns  # noqa
-from django.conf.urls import url  # noqa
+from django.urls import re_path
 
 from openstack_dashboard.dashboards.admin.metadata_defs import views
 
@@ -21,11 +20,11 @@ from openstack_dashboard.dashboards.admin.metadata_defs import views
 NAMESPACES = r'^(?P<namespace_id>[^/]+)/%s$'
 
 
-urlpatterns = patterns(
-    'openstack_dashboard.dashboards.admin.metadata_defs.views',
-    url(r'^$', views.AdminIndexView.as_view(), name='index'),
-    url(r'^create/$', views.CreateView.as_view(), name='create'),
-    url(NAMESPACES % 'detail', views.DetailView.as_view(), name='detail'),
-    url(r'^(?P<id>[^/]+)/resource_types/$',
-        views.ManageResourceTypes.as_view(), name='resource_types'),
-)
+urlpatterns = [
+    re_path(r'^$', views.AdminIndexView.as_view(), name='index'),
+    re_path(r'^create/$', views.CreateView.as_view(), name='create'),
+    re_path(NAMESPACES % 'update', views.UpdateView.as_view(), name='update'),
+    re_path(NAMESPACES % 'detail', views.DetailView.as_view(), name='detail'),
+    re_path(r'^(?P<id>[^/]+)/resource_types/$',
+            views.ManageResourceTypes.as_view(), name='resource_types'),
+]
