@@ -10,7 +10,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from django.conf.urls import url
+from django.urls import re_path
 
 from openstack_dashboard.dashboards.admin.rbac_policies import views
 
@@ -19,12 +19,12 @@ RBAC_POLICY_URL = r'^(?P<rbac_policy_id>[^/]+)/%s$'
 
 
 urlpatterns = [
-    url(r'^$', views.IndexView.as_view(), name='index'),
-    url(r'^create/$', views.CreateView.as_view(), name='create'),
-    url(RBAC_POLICY_URL % '$',
-        views.DetailView.as_view(),
-        name='detail'),
-    url(RBAC_POLICY_URL % 'update',
-        views.UpdateView.as_view(),
-        name='update'),
+    re_path(r'^$', views.IndexView.as_view(), name='index'),
+    re_path(r'^create/$', views.CreateView.as_view(), name='create'),
+    re_path(RBAC_POLICY_URL % '$',
+            views.DetailView.as_view(),
+            name='detail'),
+    re_path(RBAC_POLICY_URL % 'update',
+            views.UpdateView.as_view(),
+            name='update'),
 ]
