@@ -21,7 +21,9 @@ class VolumeTypes(horizon.Panel):
     name = _("Volume Types")
     slug = 'volume_types'
     permissions = (
-        ('openstack.services.volume',
+        ('openstack.services.block-storage',
+         'openstack.services.block-store',
+         'openstack.services.volume',
          'openstack.services.volumev3'),
     )
     policy_rules = (("volume", "volume_extension:types_manage"),)
