@@ -12,16 +12,13 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-
-from django.conf.urls import patterns
-from django.conf.urls import url
+from django.urls import re_path
 
 from openstack_dashboard.dashboards.identity.identity_providers.protocols \
     import views
 
 PORTS = r'^(?P<protocol_id>[^/]+)/%s$'
 
-urlpatterns = patterns(
-    'horizon.dashboards.identity.identity_providers.protocols.views',
-    url(r'^create/$', views.AddProtocolView.as_view(), name='create'),
-)
+urlpatterns = [
+    re_path(r'^create/$', views.AddProtocolView.as_view(), name='create'),
+]
