@@ -14,8 +14,8 @@ from django.conf import settings
 from django.template import defaultfilters as filters
 from django.urls import reverse
 from django.utils.http import urlencode
-from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import ungettext_lazy
+from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ngettext_lazy
 
 from horizon import forms
 from horizon import tables
@@ -159,17 +159,17 @@ class ModifyQuotas(tables.LinkAction):
 class DeleteTenantsAction(policy.PolicyTargetMixin, tables.DeleteAction):
     @staticmethod
     def action_present(count):
-        return ungettext_lazy(
-            u"Delete Project",
-            u"Delete Projects",
+        return ngettext_lazy(
+            "Delete Project",
+            "Delete Projects",
             count
         )
 
     @staticmethod
     def action_past(count):
-        return ungettext_lazy(
-            u"Deleted Project",
-            u"Deleted Projects",
+        return ngettext_lazy(
+            "Deleted Project",
+            "Deleted Projects",
             count
         )
 
