@@ -206,7 +206,7 @@ class CreateProjectWorkflowTests(test.BaseAdminViewTests):
         self.assertEqual(res.context['workflow'].name,
                          workflows.CreateProject.name)
 
-        self.assertQuerysetEqual(
+        self.assertQuerySetEqual(
             workflow.steps,
             ['<CreateProjectInfo: createprojectinfoaction>',
              '<UpdateProjectMembers: update_members>',
@@ -579,7 +579,7 @@ class UpdateProjectWorkflowTests(test.BaseAdminViewTests):
         self.assertEqual(step.action.initial['name'], project.name)
         self.assertEqual(step.action.initial['description'],
                          project.description)
-        self.assertQuerysetEqual(
+        self.assertQuerySetEqual(
             workflow.steps,
             ['<UpdateProjectInfo: update_info>',
              '<UpdateProjectMembers: update_members>',
@@ -1009,7 +1009,7 @@ class UpdateQuotasWorkflowTests(test.BaseAdminViewTests):
         self.assertEqual(step.action.initial['ram'], quota.get('ram').limit)
         self.assertEqual(step.action.initial['injected_files'],
                          quota.get('injected_files').limit)
-        self.assertQuerysetEqual(
+        self.assertQuerySetEqual(
             workflow.steps,
             ['<UpdateComputeQuota: update_compute_quotas>',
              '<UpdateVolumeQuota: update_volume_quotas>'],
@@ -1201,7 +1201,7 @@ class UsageViewTests(test.BaseAdminViewTests):
         self.assertTemplateUsed(res, 'project/overview/usage.csv')
 
         self.assertIsInstance(res.context['usage'], usage.ProjectUsage)
-        hdr = ('"Instance Name","VCPUs","RAM (MB)","Disk (GB)",'
+        hdr = ('"Instance Name","vCPUs","RAM (MB)","Disk (GB)",'
                '"Usage (Hours)","Age (Seconds)","State"')
         self.assertContains(res, '%s\r\n' % hdr)
 
@@ -1224,7 +1224,7 @@ class UsageViewTests(test.BaseAdminViewTests):
         res = self.client.get(csv_url)
 
         self.assertIsInstance(res.context['usage'], usage.ProjectUsage)
-        hdr = ('"Instance Name","VCPUs","RAM (MB)","Disk (GB)",'
+        hdr = ('"Instance Name","vCPUs","RAM (MB)","Disk (GB)",'
                '"Usage (Hours)","Age (Seconds)","State"')
         self.assertContains(res, '%s\r\n' % hdr)
         usage_1_quoted = ('"\'=cmd|\' /C calc\'!A0","1","512","0","122.87",'
