@@ -23,7 +23,7 @@ from django.conf import settings
 from django.urls import reverse
 from django.urls import reverse_lazy
 from django.utils.decorators import method_decorator
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.views.decorators.debug import sensitive_post_parameters
 
 from horizon import exceptions
