@@ -13,7 +13,7 @@
 #    under the License.
 
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from openstack_dashboard.dashboards.project.routers.ports import tables
 
