@@ -821,8 +821,10 @@ class NetworkPortTests(test.TestCase):
 
         self.mock_port_delete.assert_called_once_with(test.IsHttpRequest(),
                                                       port.id)
-        self.mock_port_list.assert_called_once_with(test.IsHttpRequest(),
-                                                    network_id=network_id)
+        self.mock_port_list.assert_called_once_with(
+            test.IsHttpRequest(),
+            network_id=network_id,
+            project_id=self.tenant.id)
         self.mock_is_extension_supported.assert_called_once_with(
             test.IsHttpRequest(), 'mac-learning')
 
@@ -851,7 +853,9 @@ class NetworkPortTests(test.TestCase):
 
         self.mock_port_delete.assert_called_once_with(test.IsHttpRequest(),
                                                       port.id)
-        self.mock_port_list.assert_called_once_with(test.IsHttpRequest(),
-                                                    network_id=network_id)
+        self.mock_port_list.assert_called_once_with(
+            test.IsHttpRequest(),
+            network_id=network_id,
+            project_id=self.tenant.id)
         self.mock_is_extension_supported.assert_called_once_with(
             test.IsHttpRequest(), 'mac-learning')
