@@ -15,7 +15,7 @@
 import logging
 
 from django.urls import reverse
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from horizon import exceptions
 from horizon import forms
@@ -92,6 +92,7 @@ class CreateSubnet(network_workflows.CreateNetwork):
 
 
 class UpdateSubnetInfoAction(CreateSubnetInfoAction):
+    use_required_attribute = False
     address_source = forms.ThemableChoiceField(widget=forms.HiddenInput(),
                                                required=False)
     subnetpool = forms.ThemableChoiceField(widget=forms.HiddenInput(),
@@ -156,8 +157,7 @@ class UpdateSubnetInfo(CreateSubnetInfo):
 class UpdateSubnetDetailAction(network_workflows.CreateSubnetDetailAction):
 
     def __init__(self, request, context, *args, **kwargs):
-        super(UpdateSubnetDetailAction, self).__init__(request, context,
-                                                       *args, **kwargs)
+        super().__init__(request, context, *args, **kwargs)
         # TODO(amotoki): Due to Neutron bug 1362966, we cannot pass "None"
         # to Neutron. It means we cannot set IPv6 two modes to
         # "No option selected".
@@ -219,10 +219,8 @@ class UpdateSubnet(network_workflows.CreateNetwork):
             subnet = api.neutron.subnet_update(request, subnet_id, **params)
             LOG.debug('Subnet "%s" was successfully updated.', data['cidr'])
             return subnet
-        except Exception as e:
-            msg = (_('Failed to update subnet "%(sub)s": '
-                     ' %(reason)s') %
-                   {"sub": data['cidr'], "reason": e})
+        except Exception:
+            msg = _('Failed to update subnet "%s".') % data['cidr']
             redirect = reverse(self.failure_url, args=(network_id,))
             exceptions.handle(request, msg, redirect=redirect)
             return False
