@@ -60,6 +60,7 @@
     ctrl.createKeyPair = createKeyPair;
     ctrl.importKeyPair = importKeyPair;
     ctrl.setKeypairRequired = setKeypairRequired;
+    ctrl.setAdminPasswordChange = setAdminPasswordChange;
 
     ctrl.tableData = {
       available: launchInstanceModel.keypairs,
@@ -72,7 +73,8 @@
       detailsTemplateUrl: basePath + 'keypair/keypair-details.html',
       columns: [
         {id: 'name', title: gettext('Name'), priority: 1},
-        {id: 'fingerprint', title: gettext('Fingerprint'), priority: 2}
+        {id: 'type', title: gettext('Type'), priority: 2},
+        {id: 'fingerprint', title: gettext('Fingerprint'), priority: 3}
       ]
     };
 
@@ -88,6 +90,10 @@
       label: gettext('Fingerprint'),
       name: 'fingerprint',
       singleton: true
+    }, {
+      label: gettext('Type'),
+      name: 'type',
+      singleton: true
     }];
 
     ctrl.tableLimits = {
@@ -100,6 +106,10 @@
       'OPENSTACK_HYPERVISOR_FEATURES.requires_keypair'
     ).then(setKeypairRequired);
 
+    ctrl.setAdminPassword = false;
+
+    ctrl.adminPassConfError = gettext('Passwords do not match.');
+
     //////////
 
     /**
@@ -195,6 +205,11 @@
     function setKeypairRequired(setting) {
       ctrl.isKeypairRequired = setting ? 1 : 0;
     }
+
+    function setAdminPasswordChange() {
+      ctrl.confirmedAdminPassword = null;
+      launchInstanceModel.newInstanceSpec.admin_pass = null;
+    }
   }
 
 })();
