@@ -16,7 +16,7 @@
 (function () {
   'use strict';
 
-  describe('LaunchInstanceModalController tests', function() {
+  describe('LaunchInstanceModalService tests', function() {
     var service, modal, $window;
 
     beforeEach(module('horizon.dashboard.project'));
@@ -31,8 +31,8 @@
         }
       };
       $window = { location: { href: '/' } };
-      $provide.value('$modal', modal);
-      $provide.value('$modalSpec', {});
+      $provide.value('$uibModal', modal);
+      $provide.value('$uibModalSpec', {});
       $provide.value('$window', $window);
     }));
 
