@@ -152,6 +152,7 @@
       serverGroups: [],
       volumeBootable: false,
       volumes: [],
+      volumeTypes: [],
       volumeSnapshots: [],
       metadataTree: null,
       hintsTree: null,
@@ -205,6 +206,7 @@
         hide_create_volume: false,
         vol_create: false,
         vol_delete_on_instance_delete: false,
+        vol_type: {},
         vol_size: 1
       };
     }
@@ -309,6 +311,10 @@
       if ('default_availability_zone' in defaults) {
         model.default_availability_zone = defaults.default_availability_zone;
       }
+      if ('vol_delete_on_instance_delete' in defaults) {
+        model.newInstanceSpec.vol_delete_on_instance_delete =
+          defaults.vol_delete_on_instance_delete;
+      }
     }
 
     /**
@@ -608,6 +614,8 @@
 
     function addVolumeSourcesIfEnabled(config) {
       var volumeDeferred = $q.defer();
+      var volumeTypesDeferred = $q.defer();
+      var volumeDefaultTypeDeferred = $q.defer();
       var volumeSnapshotDeferred = $q.defer();
       var absoluteLimitsDeferred = $q.defer();
       serviceCatalog
@@ -628,9 +636,13 @@
         model.allowCreateVolumeFromImage = true;
         if (!config || !config.disable_volume) {
           getVolumes().then(resolveVolumes, failVolumes);
+          getVolumeTypes().then(resolveVolumeTypes, resolveVolumeTypes);
+          getDefaultVolumeType().then(resolveDefaultVolumeType, resolveDefaultVolumeType);
           getAbsoluteLimits().then(resolveAbsoluteLimitsDeferred, resolveAbsoluteLimitsDeferred);
         } else {
           resolveVolumes();
+          resolveVolumeTypes();
+          resolveDefaultVolumeType();
           resolveAbsoluteLimitsDeferred();
         }
         if (!config || !config.disable_volume_snapshot) {
@@ -643,6 +655,12 @@
         return cinderAPI.getVolumes({status: 'available', bootable: 1})
           .then(onGetVolumes);
       }
+      function getVolumeTypes() {
+        return cinderAPI.getVolumeTypes().then(onGetVolumeTypes);
+      }
+      function getDefaultVolumeType() {
+        return cinderAPI.getDefaultVolumeType().then(onGetDefaultVolumeType);
+      }
       function getAbsoluteLimits() {
         return cinderAPI.getAbsoluteLimits().then(onGetCinderLimits);
       }
@@ -652,6 +670,8 @@
       }
       function resolvePromises() {
         volumeDeferred.resolve();
+        volumeTypesDeferred.resolve();
+        volumeDefaultTypeDeferred.resolve();
         volumeSnapshotDeferred.resolve();
         absoluteLimitsDeferred.resolve();
       }
@@ -661,6 +681,12 @@
       function failVolumes() {
         volumeDeferred.resolve();
       }
+      function resolveVolumeTypes() {
+        volumeTypesDeferred.resolve();
+      }
+      function resolveDefaultVolumeType() {
+        volumeDefaultTypeDeferred.resolve();
+      }
       function resolveVolumeSnapshots() {
         volumeSnapshotDeferred.resolve();
       }
@@ -673,6 +699,8 @@
       return $q.all(
         [
           volumeDeferred.promise,
+          volumeTypesDeferred.promise,
+          volumeDefaultTypeDeferred.promise,
           volumeSnapshotDeferred.promise,
           absoluteLimitsDeferred.promise
         ]);
@@ -749,6 +777,14 @@
       addAllowedBootSource(model.volumes, bootSourceTypes.VOLUME, gettext('Volume'));
     }
 
+    function onGetVolumeTypes(data) {
+      model.volumeTypes = data.data.items;
+    }
+
+    function onGetDefaultVolumeType(data) {
+      model.newInstanceSpec.vol_type = data.data;
+    }
+
     function onGetVolumeSnapshots(data) {
       cinderAPI.getVolumes({bootable: 1}).then(function (volumes) {
         onGetBootableVolumeSnapshots(volumes.data.items, data.data.items);
@@ -814,6 +850,7 @@
       delete finalSpec.source_type;
       delete finalSpec.vol_create;
       delete finalSpec.vol_delete_on_instance_delete;
+      delete finalSpec.vol_type;
       delete finalSpec.vol_size;
     }
 
@@ -828,6 +865,7 @@
             'delete_on_termination': finalSpec.vol_delete_on_instance_delete,
             'uuid': finalSpec.source_id,
             'boot_index': '0',
+            'volume_type': finalSpec.vol_type.name,
             'volume_size': finalSpec.vol_size
           }
         );
