@@ -168,14 +168,16 @@
         { id: 'name_or_id', title: gettext('Name'), priority: 1 },
         { id: 'updated_at', title: gettext('Updated'), filters: ['simpleDate'], priority: 2 },
         { id: 'size', title: gettext('Size'), filters: ['bytes'], priority: 2 },
-        { id: 'disk_format', title: gettext('Type'), filters: [getImageDiskFormat], priority: 2 },
+        { id: 'disk_format', title: gettext('Format'),
+          filters: [getImageDiskFormat], priority: 2 },
         { id: 'visibility', title: gettext('Visibility'), filters: [getVisibility], priority: 2 }
       ],
       snapshot: [
         { id: 'name', title: gettext('Name'), priority: 1 },
         { id: 'updated_at', title: gettext('Updated'), filters: ['simpleDate'], priority: 2 },
         { id: 'size', title: gettext('Size'), filters: ['bytes'], priority: 2 },
-        { id: 'disk_format', title: gettext('Type'), filters: [getImageDiskFormat], priority: 2 },
+        { id: 'disk_format', title: gettext('Format'),
+          filters: [getImageDiskFormat], priority: 2 },
         { id: 'visibility', title: gettext('Visibility'), filters: [getVisibility], priority: 2 }
       ],
       volume: [
@@ -265,7 +267,7 @@
         options: statuses
       },
       type: {
-        label: gettext('Type'),
+        label: gettext('Format'),
         name: 'disk_format',
         singleton: true,
         options: diskFormats
@@ -408,7 +410,7 @@
     );
 
     // When the allowedboot list changes, change the source_type
-    // and update the table for the new source selection. The devault value is
+    // and update the table for the new source selection. The default value is
     // set by the DEFAULT_BOOT_SOURCE config option.
     // The boot source is changed only if the selected value is not included
     // in the updated list (newValue)
@@ -416,7 +418,7 @@
       function getAllowedBootSources() {
         return $scope.model.allowedBootSources;
       },
-      function changeBootSource(newValue) {
+      function updateBootSource(newValue) {
         if (angular.isArray(newValue) && newValue.length > 0 ) {
           var opt = newValue[0];
           for (var index = 0; index < newValue.length; index++) {
@@ -469,7 +471,6 @@
       } else {
         $scope.model.newInstanceSpec.vol_create = false;
       }
-      $scope.model.newInstanceSpec.vol_delete_on_instance_delete = false;
       changeBootSource(selectedSource, preSelection);
       validateBootSourceType();
     }
@@ -482,8 +483,17 @@
       updateFacets(key);
     }
 
+    // Update the initial boot source selection when launching from a preselected source
     function updateDataSource(key, preSelection) {
       if (preSelection) {
+        for (var index = 0; index < $scope.model.allowedBootSources.length; index++) {
+          if ($scope.model.allowedBootSources[index].type === key) {
+            $scope.model.allowedBootSources[index].selected = true;
+          }
+          else {
+            $scope.model.allowedBootSources[index].selected = false;
+          }
+        }
         ctrl.selection.length = 0;
         push.apply(selection, preSelection);
       }
