@@ -12,7 +12,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 import horizon
 
@@ -21,7 +21,9 @@ class Volumes(horizon.Panel):
     name = _("Volumes")
     slug = 'volumes'
     permissions = (
-        ('openstack.services.volume',
+        ('openstack.services.block-storage',
+         'openstack.services.block-store',
+         'openstack.services.volume',
          'openstack.services.volumev3'),
     )
     policy_rules = (("volume", "volume:get_all"),)
