@@ -23,10 +23,8 @@ from django import shortcuts
 from django.template.defaultfilters import slugify
 from django.urls import reverse
 from django.urls import reverse_lazy
-from django.utils.decorators import method_decorator
 from django.utils import encoding
 from django.utils.translation import gettext_lazy as _
-from django.views.decorators.cache import never_cache
 from django.views import generic
 
 from horizon import exceptions
@@ -445,37 +443,54 @@ class ShowTransferView(forms.ModalFormView):
     modal_header = _("Volume Transfer")
     submit_url = "horizon:project:volumes:show_transfer"
     cancel_label = _("Close")
-    download_label = _("Download transfer credentials")
+    submit_label = _("Download transfer credentials")
     page_title = _("Volume Transfer Details")
 
+    @memoized.memoized_method
     def get_object(self):
+        transfer_id = self.kwargs['transfer_id']
         try:
-            return self._object
-        except AttributeError:
-            transfer_id = self.kwargs['transfer_id']
-            try:
-                self._object = cinder.transfer_get(self.request, transfer_id)
-                return self._object
-            except Exception:
-                exceptions.handle(self.request,
-                                  _('Unable to retrieve volume transfer.'))
+            return cinder.transfer_get(self.request, transfer_id)
+        except Exception:
+            exceptions.handle(self.request,
+                              _('Unable to retrieve volume transfer.'))
 
     def get_context_data(self, **kwargs):
+        transfer_id = self.kwargs['transfer_id']
+        auth_key = self.kwargs.get('auth_key')
         context = super().get_context_data(**kwargs)
-        context['transfer_id'] = self.kwargs['transfer_id']
-        context['auth_key'] = self.kwargs['auth_key']
-        context['download_label'] = self.download_label
-        context['download_url'] = reverse(
-            'horizon:project:volumes:download_transfer_creds',
-            args=[context['transfer_id'], context['auth_key']]
-        )
+        context.update({
+            'transfer_id': transfer_id,
+            'auth_key': auth_key,
+            'submit_url': reverse(self.submit_url, args=[transfer_id]),
+        })
         return context
 
     def get_initial(self):
         transfer = self.get_object()
-        return {'id': transfer.id,
-                'name': transfer.name,
-                'auth_key': self.kwargs['auth_key']}
+        auth_key = self.kwargs.get('auth_key')
+        if transfer:
+            return {'id': transfer.id,
+                    'name': transfer.name,
+                    'auth_key': auth_key}
+        return {}
+
+    def form_valid(self, form):
+        transfer_id = form.cleaned_data['id']
+        auth_key = form.cleaned_data['auth_key']
+        name = form.cleaned_data['name']
+        context = {'transfer': {
+            'name': name,
+            'id': transfer_id,
+            'auth_key': auth_key,
+        }}
+        response = shortcuts.render(
+            self.request,
+            'project/volumes/download_transfer_creds.html',
+            context, content_type='application/text')
+        response['Content-Disposition'] = (
+            'attachment; filename=%s.txt' % slugify(transfer_id))
+        return response
 
 
 class UpdateView(forms.ModalFormView):
@@ -667,24 +682,3 @@ class EncryptionDetailView(generic.TemplateView):
 
     def get_redirect_url(self):
         return reverse('horizon:project:volumes:index')
-
-
-class DownloadTransferCreds(generic.View):
-    @method_decorator(never_cache)
-    def get(self, request, transfer_id, auth_key):
-        try:
-            transfer = cinder.transfer_get(self.request, transfer_id)
-        except Exception:
-            transfer = None
-        context = {'transfer': {
-            'name': getattr(transfer, 'name', ''),
-            'id': transfer_id,
-            'auth_key': auth_key,
-        }}
-        response = shortcuts.render(
-            request,
-            'project/volumes/download_transfer_creds.html',
-            context, content_type='application/text')
-        response['Content-Disposition'] = (
-            'attachment; filename=%s.txt' % slugify(transfer_id))
-        return response
