@@ -23,7 +23,6 @@
 
   editService.$inject = [
     '$q',
-    'horizon.app.core.images.events',
     'horizon.app.core.images.resourceType',
     'horizon.app.core.images.actions.editWorkflow',
     'horizon.app.core.metadata.service',
@@ -42,7 +41,6 @@
    */
   function editService(
     $q,
-    events,
     imageResourceType,
     editWorkflow,
     metadataService,
@@ -103,7 +101,8 @@
           .then(onMetadataGet);
 
         function onMetadataGet(response) {
-          var updated = metadata;
+          var updated = metadata || Object();
+          updated.description = image.properties.description;
           var removed = angular.copy(response.data);
           angular.forEach(updated, function(value, key) {
             delete removed[key];
@@ -135,6 +134,5 @@
     function isActive(image) {
       return $qExtensions.booleanAsPromise(image.status === 'active');
     }
-
   } // end of editService
 })(); // end of IIFE
