@@ -25,7 +25,8 @@
     '$scope',
     'horizon.app.core.images.imageFormats',
     'horizon.app.core.images.validationRules',
-    'horizon.app.core.openstack-service-api.settings'
+    'horizon.app.core.openstack-service-api.settings',
+    'horizon.app.core.openstack-service-api.policy'
   ];
 
   /**
@@ -38,7 +39,8 @@
     $scope,
     imageFormats,
     validationRules,
-    settings
+    settings,
+    policy
   ) {
     var ctrl = this;
 
@@ -52,12 +54,11 @@
     ];
 
     ctrl.imageVisibilityOptions = [
-      { label: gettext('Public'), value: 'public' },
-      { label: gettext('Private'), value: 'private' }
+      { label: gettext('Private'), value: 'private' },
+      { label: gettext('Shared'), value: 'shared' }
     ];
 
     ctrl.setFormats = setFormats;
-    ctrl.allowPublicizeImage = { rules: [['image', 'image:publicize_image']] };
 
     $scope.imagePromise.then(init);
 
@@ -80,13 +81,26 @@
       ctrl.image.kernel = ctrl.image.properties.kernel_id;
       ctrl.image.ramdisk = ctrl.image.properties.ramdisk_id;
       ctrl.image.architecture = ctrl.image.properties.architecture;
-      ctrl.image.visibility = ctrl.image.is_public ? 'public' : 'private';
       ctrl.image_format = ctrl.image.disk_format;
       if (ctrl.image.container_format === 'docker') {
         ctrl.image_format = 'docker';
         ctrl.image.disk_format = 'raw';
       }
       setFormats();
+      getVisibilities();
+    }
+
+    function getVisibilities() {
+      policy.ifAllowed({rules: [['image', 'communitize_image']]}).then(
+        function() {
+          ctrl.imageVisibilityOptions.push({ label: gettext('Community'), value: 'community' });
+        }
+      );
+      policy.ifAllowed({rules: [['image', 'publicize_image']]}).then(
+        function() {
+          ctrl.imageVisibilityOptions.push({ label: gettext('Public'), value: 'public' });
+        }
+      );
     }
 
     function setFormats() {
@@ -99,6 +113,9 @@
         ctrl.image.container_format = 'docker';
         ctrl.image.disk_format = 'raw';
       }
+      if (ctrl.image_format === 'vhd') {
+        ctrl.image.container_format = 'ovf';
+      }
     }
 
   } // end of controller
