@@ -50,7 +50,11 @@
         "name": {
           title: gettext("Key Pair Name"),
           type: "string",
-          pattern: "^[A-Za-z0-9 -]+$"
+          pattern: "^[A-Za-z0-9 -_]+$"
+        },
+        "key_type": {
+          title: gettext("Key Type"),
+          type: "string"
         }
       }
     };
@@ -63,7 +67,7 @@
         items: [
           {
             type: "section",
-            htmlClass: "col-sm-6",
+            htmlClass: "col-sm-12",
             items: [
               {
                 key: "name",
@@ -72,20 +76,14 @@
                 },
                 $validators: {
                   keypairExists: function (name) {
-                    return (keypairs.indexOf(name) === -1);
+                    return (keypairs.indexOf(name.toLowerCase()) === -1);
                   }
                 },
                 required: true
-              }
-            ]
-          },
-          {
-            type: "section",
-            htmlClass: "col-sm-6",
-            items: [
+              },
               {
                 type: "template",
-                templateUrl: basePath + "actions/create.description.html"
+                templateUrl: basePath + "actions/create.key-type.html"
               }
             ]
           }
@@ -112,16 +110,16 @@
 
     function perform() {
       getKeypairs();
-      model = {
-        name: ""
-      };
+      model = { key_type: 'ssh' };
       var config = {
         "title": caption,
         "submitText": caption,
         "schema": schema,
         "form": form,
         "model": model,
-        "submitIcon": "plus"
+        "submitIcon": "plus",
+        "size": "md",
+        "helpUrl": basePath + "actions/create.description.html"
       };
       return modal.open(config).then(submit);
     }
@@ -153,7 +151,7 @@
     }
 
     function getName(item) {
-      return item.keypair.name;
+      return item.keypair.name.toLowerCase();
     }
   }
 })();
