@@ -40,66 +40,66 @@
 
     it('converts created_at and updated_at to human readable if calling getTrunk' +
        'or getQosPolicy',function() {
-      var data = {
+      var response = {data: {
         id: 1,
         created_at: '2017-11-16',
         updated_at: '2017-11-16'
-      };
+      }};
       spyOn(apiService, 'get').and.callFake(function() {
         return {
-          success: function(c) {
-            c(data);
+          then: function(c) {
+            c(response);
             return this;
           },
-          error: function(c) {
+          catch: function(c) {
             c();
             return this;
           }
         };
       });
-      service.getTrunk(data.id, true).success(function(result) {
-        expect(result.id).toEqual(data.id);
-        expect(result.created_at).toEqual(new Date(data.created_at));
-        expect(result.updated_at).toEqual(new Date(data.updated_at));
+      service.getTrunk(response.data.id, true).then(function(result) {
+        expect(result.data.id).toEqual(response.data.id);
+        expect(result.data.created_at).toEqual(new Date(response.data.created_at));
+        expect(result.data.updated_at).toEqual(new Date(response.data.updated_at));
       });
-      service.getQosPolicy(data.id, true).success(function(result) {
-        expect(result.id).toEqual(data.id);
-        expect(result.created_at).toEqual(new Date(data.created_at));
-        expect(result.updated_at).toEqual(new Date(data.updated_at));
+      service.getQosPolicy(response.data.id, true).then(function(result) {
+        expect(result.data.id).toEqual(response.data.id);
+        expect(result.data.created_at).toEqual(new Date(response.data.created_at));
+        expect(result.data.updated_at).toEqual(new Date(response.data.updated_at));
       });
     });
 
     it('converts created_at and updated_at to human readable if calling getTrunks' +
        'or getQoSPolicies', function() {
-      var data = {items: [{
+      var response = {data: {items: [{
         id: 1,
         created_at: '2017-11-16',
         updated_at: '2017-11-16'
-      }]};
+      }]}};
       spyOn(apiService, 'get').and.callFake(function() {
         return {
-          success: function(c) {
-            c(data);
+          then: function(c) {
+            c(response);
             return this;
           },
-          error: function(c) {
+          catch: function(c) {
             c();
             return this;
           }
         };
       });
-      service.getTrunks().success(function(result) {
-        result.items.forEach(function(trunk) {
-          expect(trunk.id).toEqual(data.items[0].id);
-          expect(trunk.created_at).toEqual(new Date(data.items[0].created_at));
-          expect(trunk.updated_at).toEqual(new Date(data.items[0].updated_at));
+      service.getTrunks().then(function(result) {
+        result.data.items.forEach(function(trunk) {
+          expect(trunk.id).toEqual(response.data.items[0].id);
+          expect(trunk.created_at).toEqual(new Date(response.data.items[0].created_at));
+          expect(trunk.updated_at).toEqual(new Date(response.data.items[0].updated_at));
         });
       });
-      service.getQoSPolicies().success(function(result) {
-        result.items.forEach(function(policy) {
-          expect(policy.id).toEqual(data.items[0].id);
-          expect(policy.created_at).toEqual(new Date(data.items[0].created_at));
-          expect(policy.updated_at).toEqual(new Date(data.items[0].updated_at));
+      service.getQoSPolicies().then(function(result) {
+        result.data.items.forEach(function(policy) {
+          expect(policy.id).toEqual(response.data.items[0].id);
+          expect(policy.created_at).toEqual(new Date(response.data.items[0].created_at));
+          expect(policy.updated_at).toEqual(new Date(response.data.items[0].updated_at));
         });
       });
     });
@@ -107,11 +107,11 @@
     it('can suppress errors in case of deleting trunks', function() {
       spyOn(apiService, 'delete').and.callFake(function() {
         return {
-          success: function(c) {
+          then: function(c) {
             c();
             return this;
           },
-          error: function(c) {
+          catch: function(c) {
             c();
             return this;
           }
@@ -119,7 +119,7 @@
       });
       spyOn(toastService, 'add').and.callThrough();
 
-      service.deleteTrunk('42', true).error(function() {
+      service.deleteTrunk('42', true).catch(function() {
         expect(toastService.add).not.toHaveBeenCalled();
       });
     });
@@ -295,7 +295,7 @@
         "method": "get",
         "path": "/api/neutron/qos_policies/",
         "data": {},
-        "error": "Unable to retrieve the qos policies."
+        "error": "Unable to retrieve the QoS policies."
       },
       {
         "func": "getQoSPolicies",
@@ -309,7 +309,7 @@
         "testInput": [
           {"project_id": 1}
         ],
-        "error": "Unable to retrieve the qos policies."
+        "error": "Unable to retrieve the QoS policies."
       },
       {
         "func": "createNetworkQoSPolicy",
@@ -325,7 +325,7 @@
         "func": "deletePolicy",
         "method": "delete",
         "path": "/api/neutron/qos_policies/63/",
-        "error": "Unable to delete qos policy 63",
+        "error": "Unable to delete QoS Policy 63",
         "testInput": [
           63
         ]
@@ -335,7 +335,7 @@
         "method": "post",
         "path": "/api/neutron/qos/policies/63/dscp_marking_rules/",
         "data": {"dscp_marking_rule":{"dscp_mark":16}},
-        "error": "Unable to add the dscp_marking_rule .",
+        "error": "Unable to add the DSCP marking rule.",
         "testInput": [63,
                 {"dscp_marking_rule":{"dscp_mark": 16}}
         ]
@@ -345,7 +345,7 @@
         "method": "post",
         "path": "/api/neutron/qos/policies/63/bandwidth_limit_rules/",
         "data": {"bandwidth_limit_rule": {"max_kbps": 10000}},
-        "error": "Unable to add the bandwidthrule .",
+        "error": "Unable to add the bandwidth rule.",
         "testInput": [63,
                 {"bandwidth_limit_rule": {"max_kbps": 10000}}
         ]
@@ -355,7 +355,7 @@
         "method": "post",
         "path": "/api/neutron/qos/policies/63/minimum_bandwidth_rules/",
         "data": {"minimum_banwdiwth_rule": {"min_kbps": 1000, "direction": "egress"}},
-        "error": "Unable to add the minimum_bandwidth_rule .",
+        "error": "Unable to add the minimum bandwidth rule.",
         "testInput": [63,
                 {"minimum_banwdiwth_rule": {"min_kbps": 1000, "direction": "egress"}}
         ]
@@ -365,7 +365,7 @@
         "method": "post",
         "path": "/api/neutron/qos/policies/63/minimum_packet_rate_rules/",
         "data": {"minimum_packet_rate_rule": {"min_kpps": 1000, "direction": "ingress"}},
-        "error": "Unable to add the minimum_packet_rate_rule.",
+        "error": "Unable to add the minimum packet rate rule.",
         "testInput": [63,
                 {"minimum_packet_rate_rule": {"min_kpps": 1000, "direction": "ingress"}}
         ]
@@ -375,7 +375,7 @@
         "method": "patch",
         "path": "/api/neutron/qos/policies/63/dscp_marking_rules/1",
         "data": {"dscp_marking_rule":{"dscp_mark":16}},
-        "error": "Unable to update the dscp marking rule.",
+        "error": "Unable to update the DSCP marking rule.",
         "testInput": [63, 1,
                 {"dscp_marking_rule":{"dscp_mark": 16}}
         ]
@@ -385,7 +385,7 @@
         "method": "patch",
         "path": "/api/neutron/qos/policies/63/bandwidth_limit_rules/1",
         "data": {"bandwidth_limit_rule": {"max_kbps": "11000"}},
-        "error": "Unable to update the bandwidthrule.",
+        "error": "Unable to update the bandwidth rule.",
         "testInput": [63, 1,
                 {"bandwidth_limit_rule": {"max_kbps": "11000"}}
         ]
@@ -414,28 +414,28 @@
         "func": "deleteDSCPMarkingRule",
         "method": "delete",
         "path": "/api/neutron/qos/policies/63/dscp_marking_rules/1",
-        "error": "Unable to delete the dscp_marking_rule.",
+        "error": "Unable to delete the DSCP marking rule.",
         "testInput": [63, 1]
       },
       {
         "func": "deleteBandwidthLimitRule",
         "method": "delete",
         "path": "/api/neutron/qos/policies/63/bandwidth_limit_rules/1",
-        "error": "Unable to delete the bandwidth_limit_rule.",
+        "error": "Unable to delete the bandwidth limit rule.",
         "testInput": [63, 1]
       },
       {
         "func": "deleteMinimumBandwidthRule",
         "method": "delete",
         "path": "/api/neutron/qos/policies/63/minimum_bandwidth_rules/1",
-        "error": "Unable to delete the minimum_bandwidth_rule .",
+        "error": "Unable to delete the minimum bandwidth rule.",
         "testInput": [63, 1]
       },
       {
         "func": "deleteMinimumPacketRateRule",
         "method": "delete",
         "path": "/api/neutron/qos/policies/63/minimum_packet_rate_rules/1",
-        "error": "Unable to delete the minimum_packet_rate_rule .",
+        "error": "Unable to delete the minimum packet rate rule.",
         "testInput": [63, 1]
       }
     ];
