@@ -73,6 +73,51 @@
         expect(result.$$state.value.data.items[0].id).toBe(1);
       }));
 
+      it('returns detailsPath with nav parameter in case of admin url', function() {
+        spyOn(_location_, 'url').and.returnValue('/admin/trunks');
+        var result = service.getDetailsPath({id:"42"});
+        expect(result).toContain('?nav=/admin/trunks/');
+      });
+
+      it('returns detailsPath without nav parameter in case of non admin url', function() {
+        spyOn(_location_, 'url').and.returnValue('/project/trunks');
+        var result = service.getDetailsPath({id:"42"});
+        expect(result).not.toContain('?nav');
+      });
+
+    });
+
+    describe('getDetailsPath', function() {
+
+      it('returns path for loading details for a given trunk', function() {
+        var trunk = {id: 1};
+        var path = service.getDetailsPath(trunk);
+        expect(path).toMatch('ngdetails');
+        expect(path).toMatch(trunk.id.toString());
+      });
+
+    });
+
+    describe('getPortDetailsPath', function() {
+
+      it('returns url to port\'s detail page for non-admin user', function() {
+        spyOn(_location_, 'url').and.returnValue('/project/trunks');
+
+        var trunk = {id: 1, port_id: 2};
+        var path = service.getPortDetailsPath(trunk);
+        expect(path).toMatch('detail');
+        expect(path).toMatch(trunk.port_id.toString());
+      });
+
+      it('returns url to port\'s detail page for admin user', function() {
+        spyOn(_location_, 'url').and.returnValue('/admin/trunks');
+
+        var trunk = {id: 1, port_id: 2};
+        var path = service.getPortDetailsPath(trunk);
+        expect(path).toMatch('detail');
+        expect(path).toMatch(trunk.port_id.toString());
+      });
+
     });
 
   });
