@@ -9,8 +9,6 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-
-from openstack_dashboard.test.integration_tests import decorators
 from openstack_dashboard.test.integration_tests import helpers
 from openstack_dashboard.test.integration_tests.regions import messages
 
@@ -19,18 +17,17 @@ class TestUser(helpers.AdminTestCase):
 
     USER_NAME = helpers.gen_random_resource_name("user")
 
-    @decorators.skip_because(bugs=['1774697'])
     def test_create_delete_user(self):
         users_page = self.home_pg.go_to_identity_userspage()
         password = self.TEST_PASSWORD
 
         users_page.create_user(self.USER_NAME, password=password,
                                project='admin', role='admin')
-        self.assertTrue(users_page.find_message_and_dismiss(messages.SUCCESS))
-        self.assertFalse(users_page.find_message_and_dismiss(messages.ERROR))
+        self.assertEqual(
+            users_page.find_messages_and_dismiss(), {messages.SUCCESS})
         self.assertTrue(users_page.is_user_present(self.USER_NAME))
 
         users_page.delete_user(self.USER_NAME)
-        self.assertTrue(users_page.find_message_and_dismiss(messages.SUCCESS))
-        self.assertFalse(users_page.find_message_and_dismiss(messages.ERROR))
+        self.assertEqual(
+            users_page.find_messages_and_dismiss(), {messages.SUCCESS})
         self.assertFalse(users_page.is_user_present(self.USER_NAME))
