@@ -14,6 +14,7 @@ import time
 
 import pytest
 from selenium.common import exceptions
+from selenium.webdriver.common.action_chains import ActionChains as AC
 from selenium.webdriver.support import expected_conditions as EC
 from selenium.webdriver.support.wait import WebDriverWait
 
@@ -41,7 +42,7 @@ def new_instance_admin(complete_default_test_network, request, instance_name,
     yield instance
     if count > 1:
         for instance in range(0, count):
-            openstack_admin.delete_server(f"{instance_name}-{instance+1}")
+            openstack_admin.delete_server(f"{instance_name}-{instance + 1}")
     else:
         openstack_admin.delete_server(instance_name)
 
@@ -55,8 +56,8 @@ def clear_instance_admin(instance_name, openstack_admin):
     )
 
 
-def wait_for_angular_readiness_instance_source(driver):
-    driver.set_script_timeout(10)
+def wait_for_angular_readiness_instance_source(driver, config):
+    driver.set_script_timeout(config.selenium.page_timeout)
     driver.execute_async_script("""
     var callback = arguments[arguments.length - 1];
     var element = document.querySelector(\
@@ -104,7 +105,7 @@ def apply_instance_name_filter(driver, config, name_pattern):
             driver.find_element_by_css_selector(
                 f".table_search input[value='{name_pattern}']")
             break
-        except(exceptions.NoSuchElementException):
+        except (exceptions.NoSuchElementException):
             time.sleep(3)
 
 
@@ -116,6 +117,15 @@ def wait_for_instance_is_deleted(openstack, instance_name):
             time.sleep(3)
 
 
+def wait_for_steady_state_of_instance(openstack, instance_name):
+    for attempt in range(120):
+        if (openstack.compute.find_server(instance_name).status in
+                ["ACTIVE", "ERROR"]):
+            break
+        else:
+            time.sleep(3)
+
+
 def test_create_instance_demo(complete_default_test_network, login, driver,
                               instance_name, openstack_demo,
                               clear_instance_demo, config):
@@ -148,7 +158,7 @@ def test_create_instance_demo(complete_default_test_network, login, driver,
     )
     widgets.select_from_transfer_table(flavor_table, flavor)
     navigation.find_element_by_link_text("Source").click()
-    wait_for_angular_readiness_instance_source(driver)
+    wait_for_angular_readiness_instance_source(driver, config)
     source_table = wizard.find_element_by_css_selector(
         "ng-include[ng-form=launchInstanceSourceForm]"
     )
@@ -170,9 +180,10 @@ def test_create_instance_demo(complete_default_test_network, login, driver,
 
 
 def test_create_instance_from_volume_demo(complete_default_test_network, login,
-                                          driver, volume_name, new_volume_demo,
-                                          clear_instance_demo, config,
-                                          openstack_demo, instance_name):
+                                          driver, volume_name,
+                                          clear_instance_demo_before_volume,
+                                          config, openstack_demo,
+                                          instance_name):
     network = complete_default_test_network.name
     flavor = config.launch_instances.flavor
     volume_name = volume_name[0]
@@ -202,7 +213,7 @@ def test_create_instance_from_volume_demo(complete_default_test_network, login,
     )
     widgets.select_from_transfer_table(flavor_table, flavor)
     navigation.find_element_by_link_text("Source").click()
-    wait_for_angular_readiness_instance_source(driver)
+    wait_for_angular_readiness_instance_source(driver, config)
     source_table = wizard.find_element_by_css_selector(
         "ng-include[ng-form=launchInstanceSourceForm]"
     )
@@ -211,7 +222,7 @@ def test_create_instance_from_volume_demo(complete_default_test_network, login,
     select_boot_sources_type_tab.click()
     select_boot_sources_type_tab.find_element_by_css_selector(
         "option[value='volume']").click()
-    delete_volume_on_instance_delete(source_table, "No")
+    delete_volume_on_instance_delete(source_table, "Yes")
     widgets.select_from_transfer_table(source_table, volume_name)
     wizard.find_element_by_css_selector("button.btn-primary.finish").click()
     WebDriverWait(driver, config.selenium.page_timeout).until(
@@ -235,7 +246,7 @@ def test_delete_instance_demo(login, driver, instance_name, openstack_demo,
     actions_column = rows[0].find_element_by_css_selector("td.actions_column")
     widgets.select_from_dropdown(actions_column, "Delete Instance")
     widgets.confirm_modal(driver)
-    messages = widgets.get_and_dismiss_messages(driver)
+    messages = widgets.get_and_dismiss_messages(driver, config)
     assert f"Info: Scheduled deletion of Instance: {instance_name}" in messages
     wait_for_instance_is_deleted(openstack_demo, instance_name)
     assert openstack_demo.compute.find_server(instance_name) is None
@@ -342,6 +353,8 @@ def test_instances_pagination_and_filtration_demo(login, driver, instance_name,
         'instances'
     ))
     driver.get(url)
+    h1 = driver.find_element_by_css_selector("h1")
+    AC(driver).move_to_element(h1).perform()
     driver.find_element_by_css_selector(
         "button[class='btn btn-default dropdown-toggle']").click()
     # set filter by instance_name
@@ -396,6 +409,8 @@ def test_filter_instances_demo(login, driver, instance_name,
         'instances'
     ))
     driver.get(url)
+    h1 = driver.find_element_by_css_selector("h1")
+    AC(driver).move_to_element(h1).perform()
     driver.find_element_by_css_selector(
         "button[class='btn btn-default dropdown-toggle']").click()
     # set filter by instance_name
@@ -451,7 +466,7 @@ def test_create_instance_admin(complete_default_test_network, login, driver,
     )
     widgets.select_from_transfer_table(flavor_table, flavor)
     navigation.find_element_by_link_text("Source").click()
-    wait_for_angular_readiness_instance_source(driver)
+    wait_for_angular_readiness_instance_source(driver, config)
     source_table = wizard.find_element_by_css_selector(
         "ng-include[ng-form=launchInstanceSourceForm]"
     )
@@ -481,7 +496,7 @@ def test_delete_instance_admin(login, driver, instance_name, openstack_admin,
     actions_column = rows[0].find_element_by_css_selector("td.actions_column")
     widgets.select_from_dropdown(actions_column, "Delete Instance")
     widgets.confirm_modal(driver)
-    messages = widgets.get_and_dismiss_messages(driver)
+    messages = widgets.get_and_dismiss_messages(driver, config)
     assert f"Info: Scheduled deletion of Instance: {instance_name}" in messages
     wait_for_instance_is_deleted(openstack_admin, instance_name)
     assert openstack_admin.compute.find_server(instance_name) is None
@@ -589,6 +604,8 @@ def test_instances_pagination_and_filtration_admin(login, driver, instance_name,
         'instances'
     ))
     driver.get(url)
+    h1 = driver.find_element_by_css_selector("h1")
+    AC(driver).move_to_element(h1).perform()
     driver.find_element_by_css_selector(
         "button[class='btn btn-default dropdown-toggle']").click()
     # set filter by instance_name
@@ -643,6 +660,8 @@ def test_filter_instances_admin(login, driver, instance_name,
         'instances'
     ))
     driver.get(url)
+    h1 = driver.find_element_by_css_selector("h1")
+    AC(driver).move_to_element(h1).perform()
     driver.find_element_by_css_selector(
         "button[class='btn btn-default dropdown-toggle']").click()
     # set filter by instance_name
