@@ -15,8 +15,8 @@ import time
 import pytest
 from selenium.webdriver.support import expected_conditions as EC
 from selenium.webdriver.support.wait import WebDriverWait
-import test_images
 
+from openstack_dashboard.test.selenium.integration import test_images
 from openstack_dashboard.test.selenium import widgets
 
 #   Import image fixtures
@@ -45,7 +45,7 @@ def wait_for_steady_state_of_volume(openstack, volume_name):
 
 
 def wait_for_volume_is_deleted(openstack, volume_name):
-    for attempt in range(10):
+    for attempt in range(120):
         if openstack.block_storage.find_volume(volume_name) is None:
             break
         else:
@@ -67,7 +67,7 @@ def test_create_empty_volume_demo(login, driver, volume_name, openstack_demo,
     volume_form.find_element_by_id("id_name").send_keys(volume_name)
     volume_form.find_element_by_css_selector(
         ".btn-primary[value='Create Volume']").click()
-    messages = widgets.get_and_dismiss_messages(driver)
+    messages = widgets.get_and_dismiss_messages(driver, config)
     assert f'Info: Creating volume "{volume_name}"' in messages
     assert openstack_demo.block_storage.find_volume(volume_name) is not None
 
@@ -94,7 +94,7 @@ def test_create_volume_via_vol_source_image_demo(login, driver,
         volume_form, 'id_image_source', image_source_name)
     volume_form.find_element_by_css_selector(
         ".btn-primary[value='Create Volume']").click()
-    messages = widgets.get_and_dismiss_messages(driver)
+    messages = widgets.get_and_dismiss_messages(driver, config)
     assert f'Info: Creating volume "{volume_name}"' in messages
     assert openstack_demo.block_storage.find_volume(volume_name) is not None
 
@@ -116,7 +116,7 @@ def test_delete_volume_demo(login, driver, volume_name, openstack_demo,
     actions_column = rows[0].find_element_by_css_selector("td.actions_column")
     widgets.select_from_dropdown(actions_column, "Delete Volume")
     widgets.confirm_modal(driver)
-    messages = widgets.get_and_dismiss_messages(driver)
+    messages = widgets.get_and_dismiss_messages(driver, config)
     assert f"Info: Scheduled deletion of Volume: {volume_name}" in messages
     wait_for_volume_is_deleted(openstack_demo, volume_name)
     assert (openstack_demo.block_storage.find_volume(volume_name) is None)
@@ -142,10 +142,10 @@ def test_edit_volume_description_demo(login, driver, volume_name, config,
     volume_form.find_element_by_id("id_description").send_keys(
         f"EDITED_Description for: {volume_name}")
     volume_form.find_element_by_css_selector(".btn-primary").click()
-    messages = widgets.get_and_dismiss_messages(driver)
+    messages = widgets.get_and_dismiss_messages(driver, config)
     assert f'Info: Updating volume "{volume_name}"' in messages
-    assert(openstack_demo.block_storage.find_volume(
-           volume_name).description == f"EDITED_Description for: {volume_name}")
+    assert (openstack_demo.block_storage.find_volume(
+        volume_name).description == f"EDITED_Description for: {volume_name}")
 
 
 def test_extend_volume_demo(login, driver, openstack_demo, new_volume_demo,
@@ -161,7 +161,7 @@ def test_extend_volume_demo(login, driver, openstack_demo, new_volume_demo,
         f"table#volumes tr[data-display='{new_volume_demo.name}']"
     )
     assert len(rows) == 1
-    assert(openstack_demo.block_storage.find_volume(
+    assert (openstack_demo.block_storage.find_volume(
         new_volume_demo.name).size == 1)
     actions_column = rows[0].find_element_by_css_selector("td.actions_column")
     widgets.select_from_dropdown(actions_column, "Extend Volume")
@@ -169,10 +169,10 @@ def test_extend_volume_demo(login, driver, openstack_demo, new_volume_demo,
     volume_form.find_element_by_id("id_new_size").send_keys(2)
     volume_form.find_element_by_css_selector(
         ".btn-primary[value='Extend Volume']").click()
-    messages = widgets.get_and_dismiss_messages(driver)
+    messages = widgets.get_and_dismiss_messages(driver, config)
     assert f'Info: Extending volume: "{new_volume_demo.name}"' in messages
     wait_for_steady_state_of_volume(openstack_demo, new_volume_demo.name)
-    assert(openstack_demo.block_storage.find_volume(
+    assert (openstack_demo.block_storage.find_volume(
         new_volume_demo.name).size == 2)
 
 
@@ -215,10 +215,10 @@ def test_volume_launch_as_instance_demo(login, driver, openstack_demo,
 #   Checking of message is skipped, we wait for refresh page
 #   and then result is checked.
 #   JJ
-    WebDriverWait(driver, config.selenium.page_timeout).until(
+    WebDriverWait(driver, config.selenium.explicit_wait).until(
         EC.invisibility_of_element_located(actions_column))
     wait_for_steady_state_of_volume(openstack_demo, new_volume_demo.name)
-    assert(openstack_demo.block_storage.find_volume(
+    assert (openstack_demo.block_storage.find_volume(
         new_volume_demo.name).attachments[0]['server_id'] ==
         openstack_demo.compute.find_server(instance_name).id)
 
@@ -244,9 +244,9 @@ def test_volume_upload_to_image_demo(login, driver, openstack_demo,
     volume_form.find_element_by_id("id_image_name").send_keys(image_names[0])
     volume_form.find_element_by_css_selector(
         ".btn-primary[value='Upload']").click()
-    messages = widgets.get_and_dismiss_messages(driver)
-    assert(f'Info: Successfully sent the request to upload volume to image for '
-           f'volume: "{new_volume_demo.name}"' in messages)
+    messages = widgets.get_and_dismiss_messages(driver, config)
+    assert ('Info: Successfully sent the request to upload volume to image for '
+            f'volume: "{new_volume_demo.name}"' in messages)
     wait_for_steady_state_of_volume(openstack_demo, new_volume_demo.name)
     assert openstack_demo.compute.find_image(image_names[0]) is not None
 
@@ -345,11 +345,11 @@ def test_manage_volume_attachments(login, driver, openstack_demo,
         f"{new_instance_demo.name} ({new_instance_demo.id})")
     attach_to_instance_form.find_element_by_css_selector(
         ".btn-primary[value='Attach Volume']").click()
-    messages = widgets.get_and_dismiss_messages(driver)
-    assert(f"Info: Attaching volume {new_volume_demo.name} to instance "
-           f"{new_instance_demo.name} on /dev/vdb." in messages)
+    messages = widgets.get_and_dismiss_messages(driver, config)
+    assert (f"Info: Attaching volume {new_volume_demo.name} to instance "
+            f"{new_instance_demo.name} on /dev/vdb." in messages)
     wait_for_steady_state_of_volume(openstack_demo, new_volume_demo.name)
-    assert(openstack_demo.block_storage.find_volume(
+    assert (openstack_demo.block_storage.find_volume(
         new_volume_demo.id).attachments[0]['server_id'] ==
         new_instance_demo.id)
 
@@ -368,11 +368,11 @@ def test_manage_volume_attachments(login, driver, openstack_demo,
         "td.actions_column").click()
     driver.find_element_by_xpath(
         ".//a[normalize-space()='Detach Volume']").click()
-    messages = widgets.get_and_dismiss_messages(driver)
-    assert(f"Success: Detaching Volume: Volume {new_volume_demo.name} "
-           f"on instance {new_instance_demo.name}" in messages)
+    messages = widgets.get_and_dismiss_messages(driver, config)
+    assert (f"Success: Detaching Volume: Volume {new_volume_demo.name} "
+            f"on instance {new_instance_demo.name}" in messages)
     wait_for_steady_state_of_volume(openstack_demo, new_volume_demo.name)
-    assert(openstack_demo.block_storage.find_volume(
+    assert (openstack_demo.block_storage.find_volume(
         new_volume_demo.id).attachments == [])
 
 
@@ -394,7 +394,7 @@ def test_create_empty_volume_admin(login, driver, volume_name, openstack_admin,
     volume_form.find_element_by_id("id_name").send_keys(volume_name)
     volume_form.find_element_by_css_selector(
         ".btn-primary[value='Create Volume']").click()
-    messages = widgets.get_and_dismiss_messages(driver)
+    messages = widgets.get_and_dismiss_messages(driver, config)
     assert f'Info: Creating volume "{volume_name}"' in messages
     assert openstack_admin.block_storage.find_volume(volume_name) is not None
 
@@ -420,7 +420,7 @@ def test_create_volume_via_vol_source_image_admin(login, driver, volume_name,
         volume_form, 'id_image_source', image_source_name)
     volume_form.find_element_by_css_selector(
         ".btn-primary[value='Create Volume']").click()
-    messages = widgets.get_and_dismiss_messages(driver)
+    messages = widgets.get_and_dismiss_messages(driver, config)
     assert f'Info: Creating volume "{volume_name}"' in messages
     assert openstack_admin.block_storage.find_volume(volume_name) is not None
 
@@ -442,7 +442,7 @@ def test_delete_volume_admin(login, driver, volume_name, openstack_admin,
     actions_column = rows[0].find_element_by_css_selector("td.actions_column")
     widgets.select_from_dropdown(actions_column, "Delete Volume")
     widgets.confirm_modal(driver)
-    messages = widgets.get_and_dismiss_messages(driver)
+    messages = widgets.get_and_dismiss_messages(driver, config)
     assert f"Info: Scheduled deletion of Volume: {volume_name}" in messages
     wait_for_volume_is_deleted(openstack_admin, volume_name)
     assert (openstack_admin.block_storage.find_volume(volume_name) is None)
@@ -468,10 +468,10 @@ def test_edit_volume_description_admin(login, driver, volume_name, config,
     volume_form.find_element_by_id("id_description").send_keys(
         f"EDITED_Description for: {volume_name}")
     volume_form.find_element_by_css_selector(".btn-primary").click()
-    messages = widgets.get_and_dismiss_messages(driver)
+    messages = widgets.get_and_dismiss_messages(driver, config)
     assert f'Info: Updating volume "{volume_name}"' in messages
-    assert(openstack_admin.block_storage.find_volume(
-           volume_name).description == f"EDITED_Description for: {volume_name}")
+    assert (openstack_admin.block_storage.find_volume(
+        volume_name).description == f"EDITED_Description for: {volume_name}")
 
 
 @pytest.mark.parametrize('volume_name', [3], indirect=True)
