@@ -17,7 +17,6 @@ def load_test_data(load_onto=None):
     from openstack_dashboard.test.test_data import cinder_data
     from openstack_dashboard.test.test_data import exceptions
     from openstack_dashboard.test.test_data import glance_data
-    from openstack_dashboard.test.test_data import heat_data
     from openstack_dashboard.test.test_data import keystone_data
     from openstack_dashboard.test.test_data import neutron_data
     from openstack_dashboard.test.test_data import nova_data
@@ -32,7 +31,6 @@ def load_test_data(load_onto=None):
         cinder_data.data,
         neutron_data.data,
         swift_data.data,
-        heat_data.data,
     )
     if load_onto:
         for data_func in loaders:
