@@ -12,13 +12,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import mock
+from unittest import mock
 
 from openstack_dashboard import api
 from openstack_dashboard.test import helpers as test
 
 
-class ConfigRestTestCase(test.TestCase):
+class ConfigRestTestCase(test.RestAPITestCase):
 
     @mock.patch.object(api.glance, 'get_image_schemas')
     def test_settings_config_get(self, mock_schemas_list):
