@@ -1,3 +1,5 @@
+# Copyright 2017 Red Hat, Inc.
+#
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
 #    a copy of the License at
@@ -10,16 +12,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf import settings
-
-from horizon.utils.memoized import memoized  # noqa
+from openstack_dashboard import api
 
 
-class IdentityMixIn(object):
-    @memoized
-    def get_admin_roles(self):
-        _admin_roles = [role.lower() for role in getattr(
-            settings,
-            'OPENSTACK_KEYSTONE_ADMIN_ROLES',
-            ['admin'])]
-        return _admin_roles
+def get_domain_id_for_operation(request):
+    """Get the ID of the domain in which the current operation should happen.
+
+    If the user has a domain context set, use that, otherwise use the user's
+    effective domain.
+    """
+
+    domain_context = request.session.get('domain_context')
+    if domain_context:
+        return domain_context
+    return api.keystone.get_effective_domain_id(request)
